************
Installation
************


Installing |coadd|
========================

The easiest way to install |coadd| is with PyPi.

.. code-block:: bash

    pip install coadd

To get the very latest version of the software, install it directly from GitHub.
    
.. code-block:: bash

    pip install git+https://github.com/dnidever/coadd

    

Dependencies
============

- numpy
- scipy
- astropy
- matplotlib
- dlnpyutils
- healpy
- sep
- swarp
